<?php
/**
 * Theme functions and definitions
 *
 * @package Blogtag
 */

if ( ! function_exists( 'blogtag_enqueue_styles' ) ) :
	/**
	 * @since 0.1
	 */
	function blogtag_enqueue_styles() {
		wp_enqueue_style('bootstrap', get_template_directory_uri() . '/css/bootstrap.css');
		wp_enqueue_style( 'blogdata-style-parent', get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'blogtag-style', get_stylesheet_directory_uri() . '/style.css', array( 'blogdata-style-parent' ), '1.0' );
		wp_enqueue_style( 'blogtag-default-css', get_stylesheet_directory_uri()."/css/colors/default.css" );
		wp_enqueue_style( 'blogtag-dark', get_stylesheet_directory_uri() . '/css/colors/dark.css');

		if(is_rtl()){
			wp_enqueue_style( 'blogdata_style_rtl', trailingslashit( get_template_directory_uri() ) . 'style-rtl.css' );
	    }
		
	}

endif;
add_action( 'wp_enqueue_scripts', 'blogtag_enqueue_styles', 9999 );

function blogtag_customizer_rid_values($wp_customize) {

	$wp_customize->remove_section('header_advert_section');
	
}
add_action( 'customize_register', 'blogtag_customizer_rid_values', 1000 );

function blogtag_theme_setup() {
	//Load text domain for translation-ready
	load_theme_textdomain('blogtag', get_stylesheet_directory() . '/languages');

	require( get_stylesheet_directory() . '/customizer-default.php' );
	require( get_stylesheet_directory() . '/general-options.php' );
	require( get_stylesheet_directory() . '/hooks/header-hook.php' );
	require( get_stylesheet_directory() . '/font.php' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'automatic-feed-links' );
} 
add_action( 'after_setup_theme', 'blogtag_theme_setup' );


if( ! function_exists( 'blogtag_add_menu_description' ) ) :
    
    function blogtag_add_menu_description( $item_output, $item, $depth, $args ) {
        if($args->theme_location != 'primary') return $item_output;
        
        if ( !empty( $item->description ) ) {
            $item_output = str_replace( $args->link_after . '</a>', '<span class="menu-link-description">' . $item->description . '</span>' . $args->link_after . '</a>', $item_output );
        }
        return $item_output;
    }
    add_filter( 'walker_nav_menu_start_el', 'blogtag_add_menu_description', 10, 4 );
endif;

$args = array(
    'default-color' => '#f4f4f4',
    'default-image' => '',
	);
add_theme_support( 'custom-background', $args );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function blogtag_widgets_init() {

	$blogdata_footer_column_layout = esc_attr(get_theme_mod('blogdata_footer_column_layout',3));
	
	$blogdata_footer_column_layout = 12 / $blogdata_footer_column_layout;
	
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar Widget Area', 'blogtag' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<div id="%1$s" class="bs-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="bs-widget-title"><h2 class="title">',
		'after_title'   => '</h2></div>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Area', 'blogtag' ),
		'id'            => 'footer_widget_area',
		'description'   => '',
		'before_widget' => '<div id="%1$s" class="col-md-'.$blogdata_footer_column_layout.' rotateInDownLeft animated bs-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="bs-widget-title"><h2 class="title">',
		'after_title'   => '</h2></div>',
	) );

}
add_action( 'widgets_init', 'blogtag_widgets_init' );

function blogtag_custom_css(){ ?>
<style>	
	.site-branding-text .site-title a:hover{
		color: <?php echo esc_attr(get_theme_mod('header_text_color_on_hover','#0d6eff'))?> !important;
	}
	body.dark .site-branding-text .site-title a:hover{
		color: <?php echo esc_attr(get_theme_mod('header_text_dark_color_on_hover','#0d6eff'))?> !important;
	}
</style>
<script>
	(function($) {
		"use strict";
		function applyTabNavigation(selector) {
		$(document).ready(function() {
			$(selector).each(function() {
				var $capture = $(this);

				$capture
				.attr('tabindex', '-1')
				.focus()
				.keydown(function handleKeydown(event) {
					if (event.key.toLowerCase() !== 'tab') {
						return;
					}
					var tabbable = $()
					.add($capture.find('button, input, select, textarea'))
					.add($capture.find('[href]'))
					.add($capture.find('[tabindex]:not([tabindex="-1"])'));

					var $target = $(event.target);

					if (tabbable.length === 0) {
						return;
					}
					var firstTabbable = tabbable.first();
					var lastTabbable = tabbable.last();
					if (event.shiftKey) { 
						if ($target.is(firstTabbable)) {
							event.preventDefault();
							lastTabbable.focus();
						}
					} else { 
						if ($target.is(lastTabbable)) {
							event.preventDefault();
							firstTabbable.focus();
						}
					}
				});

				// Ensure focus starts within the container when it's focused
				$capture.on('focus', function() {
					var tabbable = $()
					.add($capture.find('button, input, select, textarea'))
					.add($capture.find('[href]'))
					.add($capture.find('[tabindex]:not([tabindex="-1"])'));

					if (tabbable.length > 0) {
						tabbable.first().focus();
					}
				});
			});
		});
		}

		// Apply to multiple selectors
		applyTabNavigation('.search-popup');
		applyTabNavigation('.bs-offcanvas.end');

		
		function onClickFocus(clickableSelector, focusableSelector) {
			const clickableElements = document.querySelectorAll(clickableSelector);

			// Iterate over each clickable element
			clickableElements.forEach(clickableElement => {
				// Add click event listener to the clickable element
				clickableElement.addEventListener('click', function() {
				// Find the focusable element
				const focusableElement = document.querySelector(focusableSelector);
				if (focusableElement) {
					// Focus on the focusable element
					focusableElement.focus();
				}
				});
			});
		}

		onClickFocus('[bs-data-clickable-end]', '[bs-data-removable]');
		onClickFocus('[bs-data-removable]', '[bs-data-clickable-end]');
		onClickFocus('[bs-search-clickable]', '[bs-dismiss-search]');
		onClickFocus('[bs-dismiss-search]', '[bs-search-clickable]');

	})(jQuery);
</script>
<?php
} 
add_action('wp_footer', 'blogtag_custom_css',999);

function blogtag_customizer_styles() {
	?>
	<style>
		body #accordion-section-blogdata_pro_upsell h3 .button-secondary:hover{
			color: #0d6eff !important;
			border-color: currentcolor;
		}
	</style>
	<?php
}
add_action('customize_controls_enqueue_scripts', 'blogtag_customizer_styles');







add_action('init', function() {
    add_rewrite_rule('^offers-1/?$', 'index.php?pagename=offers-1', 'top');
    add_rewrite_rule('^offers-2/?$', 'index.php?pagename=offers-2', 'top');
	add_rewrite_rule('^offers-3/?$', 'index.php?pagename=offers-3', 'top');
    
    // Aggiunge le variabili di query per essere sicuri che WordPress le riconosca
    add_filter('query_vars', function($vars) {
        $vars[] = 'utm_content';
        $vars[] = 'utm_term';
        $vars[] = 'utm_source';
        $vars[] = 'utm_medium';
        $vars[] = 'ref_id';
        $vars[] = 'gclid';
        return $vars;
    });
});

add_action('init', function() {
    add_rewrite_rule('^offers-3/?$', 'index.php?pagename=offers-3', 'top');
});


add_action('template_redirect', function() {
    $pageName = get_query_var('pagename');
    
    if ($pageName === 'offers-1' || $pageName === 'offers-2' || $pageName === 'offers-3') {
        // Recupera i parametri di query sanitizzati
        $utm_content = sanitize_text_field(get_query_var('utm_content'));
        $utm_term = sanitize_text_field(get_query_var('utm_term'));
        $utm_source = sanitize_text_field(get_query_var('utm_source'));
        $utm_medium = sanitize_text_field(get_query_var('utm_medium'));
        $ref_id = sanitize_text_field(get_query_var('ref_id'));
        $gclid = sanitize_text_field(get_query_var('gclid'));

        // URL di destinazione per ciascuna pagina
        if ($pageName === 'offers-1') {
            $redirectUrl = 'https://news.strongcasino.uk/67b853ca0548200c1e28ced1';
        } elseif ($pageName === 'offers-2') {
            $redirectUrl = 'https://news.strongcasino.uk/67b853cc5d0a44eda9aa8b2f';
        } elseif ($pageName === 'offers-3') {
            $redirectUrl = 'https://news.strongcasino.uk/67b853cc5d0a44eda9aa8b2f';
        }

        // Aggiungi i parametri all'URL
        $redirectUrl .= "?utm_content={$utm_content}&utm_term={$utm_term}&utm_source={$utm_source}&utm_medium={$utm_medium}&ref_id={$ref_id}&gclid={ref_id}";

        // Effettua il reindirizzamento con tutti i parametri inclusi
        if ($utm_content && $utm_term && $utm_source && $utm_medium && $ref_id && $gclid) {
            wp_redirect($redirectUrl, 301);
            exit;
        }
    }
});



add_action('init', function() {
    add_rewrite_rule('^offers-1$', 'index.php?pagename=offers-1', 'top');
    // flush_rewrite_rules(false);
});

add_action('template_redirect', function() {
    if (get_query_var('pagename') === 'offers-1') {
        // Check if all necessary parameters are set
        if (isset($_GET['utm_content'], $_GET['utm_term'], $_GET['utm_source'], $_GET['utm_medium'], $_GET['ref_id'])) {
            // Sanitize each parameter
            $utm_content = sanitize_text_field($_GET['utm_content']);
            $utm_term = sanitize_text_field($_GET['utm_term']);
            $utm_source = sanitize_text_field($_GET['utm_source']);
            $utm_medium = sanitize_text_field($_GET['utm_medium']);
            $ref_id = sanitize_text_field($_GET['ref_id']);
            
            // Redirect with all parameters
            wp_redirect("https://news.strongcasino.uk/67b853ca0548200c1e28ced1?utm_content={$utm_content}&utm_term={$utm_term}&utm_source={$utm_source}&utm_medium={$utm_medium}&ref_id={$ref_id}&gclid={$ref_id}", 301);
            exit;
        }
    }
});



function add_custom_script_footer() {
    ?>
    <script>
    document.addEventListener('DOMContentLoaded', function () {
        // Script per age-gate
        var buttonNo = document.querySelector('.age-gate__submit--no');
        var buttonYes = document.querySelector('.age-gate__submit--yes');

        function handleButtonClick(e, path, includeParams) {
            e.preventDefault();

            var rootURL = window.location.protocol + '//' + window.location.host;
            var destinationURL = rootURL + path;

            console.log('Root URL:', rootURL);
            console.log('Initial Destination URL:', destinationURL);

            if (includeParams) {
                var queryString = window.location.search;
                var urlParams = new URLSearchParams(queryString);

                var utm_content = urlParams.get('utm_content');
                var utm_term = urlParams.get('utm_term');
                var utm_source = urlParams.get('utm_source');
                var utm_medium = urlParams.get('utm_medium');
                var ref_id = urlParams.get('ref_id');
                
                console.log('utm_content:', utm_content);
                console.log('utm_term:', utm_term);
                console.log('utm_source:', utm_source);
                console.log('utm_medium:', utm_medium);
                console.log('ref_id:', ref_id);
                
                // Simple check for mobile device
                var isMobile = /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent);
                console.log('Is Mobile:', isMobile);

                if (isMobile) {
                    var intermediateURL = `${rootURL}/offers-1?utm_content=${utm_content}&utm_term=${utm_term}&utm_source=${utm_source}&utm_medium=${utm_medium}&ref_id=${ref_id}&gclid=${ref_id}`;

                    console.log('Intermediate URL:', intermediateURL);

                    window.location.href = intermediateURL;
                    return;
                }
            }

            window.location.href = destinationURL;
        }

        if (buttonNo) {
            buttonNo.addEventListener('click', function (e) {
                var path = '/termos-de-uso-do-site/';
                handleButtonClick(e, path, false);
            });
        }

        if (buttonYes) {
            buttonYes.addEventListener('click', function (e) {
                var path = '/category/uncategorized/';
                handleButtonClick(e, path, true);
            });
        }

    // Script per i bottoni su 'offer-wall'
if (window.location.pathname.includes('offer-wall')) {
    // Seleziona tutti i pulsanti che puntano a /offers-2 e /offers-3
    var buttonsOffers2 = document.querySelectorAll('a[href="/offers-2"]');
    var buttonsOffers3 = document.querySelectorAll('a[href="/offers-3"]');

    function handleButtonClick(buttons, destinationPath) {
        buttons.forEach(function(button) {
            button.addEventListener('click', function(e) {
                e.preventDefault();

                var rootURL = window.location.protocol + '//' + window.location.host;
                var destinationURL = rootURL + destinationPath;

                var queryString = window.location.search;
                var urlParams = new URLSearchParams(queryString);

                var utm_content = urlParams.get('utm_content');
                var utm_term = urlParams.get('utm_term');
                var utm_source = urlParams.get('utm_source');
                var utm_medium = urlParams.get('utm_medium');
                var ref_id = urlParams.get('ref_id');
                var gclid = urlParams.get('gclid'); // retrieving gclid

                // Controlla se tutti i parametri sono presenti
                if (utm_content && utm_term && utm_source && utm_medium && ref_id && gclid) {
                    // Crea l'URL di reindirizzamento con tutti i parametri
                    var intermediateURL = `${destinationURL}?utm_content=${utm_content}&utm_term=${utm_term}&utm_source=${utm_source}&utm_medium=${utm_medium}&ref_id=${ref_id}&gclid=${ref_id}`;

                    // Effettua il reindirizzamento
                    window.location.href = intermediateURL;
                } else {
                    // Se i parametri non sono tutti presenti, effettua comunque il reindirizzamento
                    window.location.href = destinationURL;
                }
            });
        });
    }

    // Gestisci i click sui pulsanti che puntano a /offers-2
    handleButtonClick(buttonsOffers2, '/offers-2');

    // Gestisci i click sui pulsanti che puntano a /offers-3
    handleButtonClick(buttonsOffers3, '/offers-3');
}

    });
    </script>
}
<?php

}
add_action('wp_footer', 'add_custom_script_footer');
?>
